@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Application\Modules;
 
@@ -671,6 +671,8 @@ class Module
                             $metadata->description .= $line;
                             continue;
                         }
+                    } elseif (empty($line)) {
+                        continue;
                     }
 
                     list($key, $val) = preg_split('/:\s+/', $line, 2);
@@ -1289,7 +1291,7 @@ class Module
             $class = $implementation;
         }
 
-        Hook::register($name, $implementation, $class);
+        Hook::register($name, $class, $class);
         return $this;
     }
 
