@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Authentication\UserGroup;
 
@@ -705,7 +705,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
             ->setGroupNameAttribute($config->get('group_name_attribute', $defaults->group_name_attribute))
             ->setUserNameAttribute($config->get('user_name_attribute', $defaults->user_name_attribute))
             ->setGroupMemberAttribute($config->get('group_member_attribute', $defaults->group_member_attribute))
-            ->setGroupFilter($config->filter)
+            ->setGroupFilter($config->group_filter)
             ->setUserFilter($config->user_filter);
     }
 
