@@ -1,10 +1,12 @@
 <?php
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
+
 namespace Icinga\Web\View;
 
-use Icinga\Util\String;
+use Icinga\Util\StringHelper;
 
 $this->addHelperFunction('ellipsis', function ($string, $maxLength, $ellipsis = '...') {
-    return String::ellipsis($string, $maxLength, $ellipsis);
+    return StringHelper::ellipsis($string, $maxLength, $ellipsis);
 });
 
 $this->addHelperFunction('nl2br', function ($string) {
